@@ -207,7 +207,7 @@ courseEmpty = Course(
     license=license1,
     modules=[],
     dictionary=fake_dictionary,
-    repositoryUrl="https://github.com/kantord/LibreLingo/tree/main/courses/spanish-from-english"
+    repository_url="https://github.com/kantord/LibreLingo/tree/main/courses/spanish-from-english"
 )
 
 
@@ -225,7 +225,7 @@ course1 = Course(
         Module(title="Phrases", skills=[]),
     ],
     dictionary=fake_dictionary,
-    repositoryUrl="https://github.com/kantord/LibreLingo/tree/main/courses/spanish-from-english"
+    repository_url="https://github.com/kantord/LibreLingo/tree/main/courses/spanish-from-english"
 )
 
 course2 = Course(
@@ -239,7 +239,7 @@ course2 = Course(
         ]),
     ],
     dictionary=fake_dictionary,
-    repositoryUrl="https://github.com/kantord/LibreLingo-Spanish-from-English"
+    repository_url="https://github.com/kantord/LibreLingo-Spanish-from-English"
 )
 
 
